mchammer.MCStepResult
=====================

.. currentmodule:: mchammer

.. autoclass:: MCStepResult
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~MCStepResult.get_properties
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~MCStepResult.passed
      ~MCStepResult.step
      ~MCStepResult.log
      ~MCStepResult.position_matrix
      ~MCStepResult.system_potential
      ~MCStepResult.nonbonded_potential
      ~MCStepResult.max_bond_distance
   
   